var db = require("../db/pool");
var _ = require('lodash');

/**
 * 保存Json到指的的表中。
 * @param {*} json 要保存的数据
 * @param {*} table  数据表名称
 * @param {*} key 主键名称
 */
var saveJsonToDb = (json, table, key) => {
    return new Promise((resovle, reject) => {
        var sql = "";
        if (_.has(json, key) && _.get(json, key, 0) > 0) {
            var id = _.get(json, key);
            _.unset(json, key);
            var where = {};
            where[key] = id;
            // update
            sql = db.sql.$update({
                $table: table,
                $set: json,
                $where: where
            });
        } else {
            _.unset(json, key);
            // insert
            sql = db.sql.$insert({
                $table: table,
                $documents: json
            });
        }
        db.query(sql.sql, sql.values)
            .then((rows) => {
                resovle({ ok: 1 });
            }).catch((err) => {
                reject(JSON.stringify(err));
            });
    });
};

/**
 * 通过json条件获取数据库内数据列表
 * @param {*} json 查询条件
 * @param {*} table 数据表名称
 * @param {*} items 要查询的字段
 */
var listDbByJson = (json, table, items) => {
    return new Promise((resovle, reject) => {
        var query = {};
        //整理字段
        if (_.isString(items) && items != "*") {
            //单独项目查询
            var map = {};
            map[items] = true;
            query['$columns'] = map;
        } else if (_.isArray(items)) {
            var map = {};
            items.forEach((v) => {
                map[v] = true;
            })
            query['$columns'] = map;
        } else if (_.isObject(items)) {
            var citems = Object.assign({}, items);
            query = _.merge(query, citems);
        }

        var cloned = Object.assign({}, json);
        query['$where'] = cloned;
        query['$from'] = table;
        
        var sql = db.sql.$select(query);

        db.query(sql.sql, sql.values)
            .then((rows) => {
                resovle(rows);
            }).catch((err) => {
                reject(JSON.stringify(err));
            });
    });
}

module.exports = {
    saveJsonToDb,
    listDbByJson,
}